@@ -28,7 +28,7 @@ public:
         if (!parent) {
             return -1;
         } else if (parent->isWidgetType()) {
-            QWidget *pw = static_cast<QWidget *>(parent);
+            auto pw = static_cast<QWidget *>(parent);
             return pw->style()->pixelMetric(pm, nullptr, pw);
         } else {
             return static_cast<QLayout *>(parent)->spacing();
@@ -42,7 +42,7 @@ public:
 
     Qt::Alignment alignment;
 
-    KBlockLayout *q;
+    KBlockLayout *q = nullptr;
 };
 
 KBlockLayout::KBlockLayout(QWidget *parent, int margin, int hSpacing, int vSpacing)
@@ -150,11 +150,22 @@ void KBlockLayout::setGeometry(const QRect &rect)
     doLayout(rect, false);
 }
 
+int KBlockLayout::getMargin() const
+{
+    int left, top, right, bottom;
+    getContentsMargins(&left, &top, &right, &bottom);
+    if (left == top && top == right && right == bottom) {
+        return left;
+    } else {
+        return -1;
+    }
+}
+
 QSize KBlockLayout::sizeHint() const
 {
     // TODO: try to get the items into a square
     QSize size;
-    for (QLayoutItem *item : qAsConst(d->itemList)) {
+    for (QLayoutItem *item : std::as_const(d->itemList)) {
         const QSize itemSize = item->minimumSize();
         size.rwidth() += itemSize.width();
         if (itemSize.height() > size.height()) {
@@ -163,18 +174,18 @@ QSize KBlockLayout::sizeHint() const
     }
 
     size.rwidth() += horizontalSpacing() * d->itemList.count();
-    size += QSize(2 * margin(), 2 * margin());
+    size += QSize(2 * getMargin(), 2 * getMargin());
     return size;
 }
 
 QSize KBlockLayout::minimumSize() const
 {
     QSize size;
-    for (QLayoutItem *item : qAsConst(d->itemList)) {
+    for (QLayoutItem *item : std::as_const(d->itemList)) {
         size = size.expandedTo(item->minimumSize());
     }
 
-    size += QSize(2 * margin(), 2 * margin());
+    size += QSize(2 * getMargin(), 2 * getMargin());
     return size;
 }
 
@@ -227,14 +238,14 @@ int KBlockLayout::doLayout(const QRect &rect, bool testOnly) const
 
     // 2. place the items
     y = rect.y();
-    for (const Row &row : qAsConst(rows)) {
+    for (const Row &row : std::as_const(rows)) {
         x = rect.x();
         if (alignment() & Qt::AlignRight)
             x += (rect.width() - row.width);
         else if (alignment() & Qt::AlignHCenter)
             x += (rect.width() - row.width) / 2;
 
-        for (QLayoutItem *item : qAsConst(row.items)) {
+        for (QLayoutItem *item : std::as_const(row.items)) {
             int yy = y;
             if (alignment() & Qt::AlignBottom)
                 yy += (row.height - item->sizeHint().height());
